#
# spec file for package mvapich2-testsuite
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#############################################################################
#                                                                           #
# NOTE: If you modify this spec file, or the .changes file you MUST run     #
#       'bash ./pre_checkin.sh' to create spec and changes for              #
#       mvapich2-testuite.                                                  #
#                                                                           #
#############################################################################

%define rc_ver rc1

Name:           mvapich2-testsuite
Summary:        OSU MVAPICH2 MPI package
License:        BSD-3-Clause
Group:          Development/Libraries/Parallel
Version:        2.2
Release:        1.21
Source0:        http://mvapich.cse.ohio-state.edu/download/mvapich2/mv2/mvapich2-%{version}%{?rc_ver}.tar.gz
Source1:        mpivars.sh
Source2:        mpivars.csh
Patch0:         mvapich-s390_get_cycles.patch
Patch1:         mvapich2-pthread_yield.patch
Url:            http://mvapich.cse.ohio-state.edu/overview/mvapich2/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  libibmad-devel
BuildRequires:  libibumad-devel
BuildRequires:  libibverbs-devel
%ifnarch s390 s390x
BuildRequires:  libnuma-devel
%endif
BuildRequires:  librdmacm-devel
BuildRequires:  libtool
BuildRequires:  libtool
BuildRequires:  mpi-selector
BuildRequires:  python-devel
BuildRequires:  sysfsutils
BuildRequires:  xorg-x11-devel
# mvapich needs asm/timex.h which seems to be missing from the glibc kernel headers
ExcludeArch:    aarch64

%if "%{name}" == "mvapich2-psm"
ExclusiveArch:  %ix86 x86_64
BuildRequires:  infinipath-psm-devel
%ifarch x86_64
BuildRequires:  libpsm2-devel
%endif
%endif

Requires:       mpi-selector

%define _prefix /usr/%_lib/mpi/gcc/mvapich2
%define _libexecdir %{_prefix}/%{_lib}
%define _benchmarkdir %{_libexecdir}/osu-micro-benchmarks

%description
This is an MPI-3 implementation which includes all MPI-1 features. It
is based on MPICH2 and MVICH.

%if "%{name}" == "mvapich2" || "%{name}" == "mvapich2-psm"

%package        devel
Summary:        OSU MVAPICH2 MPI package
Group:          Development/Libraries/Parallel
Requires:       %{name} = %{version}
Requires:       libibumad-devel
Requires:       libibverbs-devel
Requires:       librdmacm-devel
%if "%{name}" == "mvapich2-psm"
Requires:       infinipath-psm-devel
%ifarch x86_64
Requires:       libpsm2-devel
%endif
%endif

%description devel
This is an MPI-2 implementation which includes all MPI-1 features.  It
is based on MPICH2 and MVICH.



%package        devel-static
Summary:        OSU MVAPICH2 MPI package - static libraries
Group:          Development/Libraries/Parallel
Requires:       %{name}-devel = %{version}

%description devel-static
This is an MPI-3 implementation which includes all MPI-1 and MPI-2 features.  It
is based on MPICH2 and MVICH. This package contains the static libraries

%endif

%prep
%setup -q -n mvapich2-%{version}%{?rc_ver}
%patch0
%patch1
cp /usr/share/automake*/config.* .

%build
#./autogen.sh
%configure  --prefix=%_prefix --libdir=%_libdir --mandir=%_mandir --sysconfdir=%_sysconfdir --libexecdir=%{_libexecdir} \
%if "%{name}" == "mvapich2-psm"
   --with-device=ch3:psm \
%endif
    --enable-shared --without-mpe --disable-silent-rules
make %{?_smp_mflags}

%if "%{name}" == "mvapich2-testsuite"
%check
make check
%endif

%install
make DESTDIR=%{buildroot} install
# make and install mpivars files
sed 's,prefix,%_prefix,g' %{S:1} > %{buildroot}%{_bindir}/mpivars.sh
sed 's,prefix,%_prefix,g' %{S:2} > %{buildroot}%{_bindir}/mpivars.csh
rm -f %{buildroot}%{_libdir}/libfmpich.la \
      %{buildroot}%{_libdir}/libmpich.la \
      %{buildroot}%{_libdir}/libmpichcxx.la \
      %{buildroot}%{_libdir}/libmpichf90.la \
      %{buildroot}%{_libdir}/libmpl.la \
      %{buildroot}%{_libdir}/libopa.la \
      %{buildroot}%{_libdir}/libmpi.la \
      %{buildroot}%{_libdir}/libmpicxx.la \
      %{buildroot}%{_libdir}/libmpifort.la 

%if "%{name}" == "mvapich2-testsuite"
rm -rf %{buildroot}%{_libdir}/pkgconfig
rm -rf %{buildroot}%{_includedir}
rm -rf %{buildroot}%{_mandir}/man3/*
rm -rf %{buildroot}%{_libdir}/*.so
rm -rf %{buildroot}%{_libdir}/pkgconfig/mvapich2.pc
rm -rf %{buildroot}%{_libdir}/pkgconfig/openpa.pc

rm -rf %{buildroot}%{_libdir}/*.a
%endif

install -m 0644 COPYRIGHT* %{buildroot}%{_datadir}/doc/mvapich2
install -m 0644 CHANGE* %{buildroot}%{_datadir}/doc/mvapich2

%post
/sbin/ldconfig
/usr/bin/mpi-selector \
        --register %{name}-%{version} \
        --source-dir %{_bindir} \
        --yes

%postun
/sbin/ldconfig
/usr/bin/mpi-selector --unregister %{name}-%{version} --yes --silent

%files
%defattr(-, root, root)
%doc %{_datadir}/doc
%dir /usr/%_lib/mpi
%dir /usr/%_lib/mpi/gcc
%dir /usr/%_lib/mpi/gcc/mvapich2
%dir %{_prefix}
%dir %{_bindir}
%dir %{_datadir}
%if "%{name}" == "mvapich2"
%dir %{_includedir}
%endif
%dir %{_mandir}
%dir %{_mandir}/man1
%dir %{_mandir}/man3
%dir %{_libdir}
%dir %{_libdir}
%{_bindir}/*
%{_benchmarkdir}

%{_mandir}/man1/*
%{_libdir}/*.so.*

%if "%{name}" == "mvapich2" || "%{name}" == "mvapich2-psm"
%files devel
%defattr(-,root,root)
%dir %{_libdir}/pkgconfig
%{_mandir}/man3/*
%{_includedir}
%{_libdir}/*.so
%{_libdir}/pkgconfig/mvapich2.pc
%{_libdir}/pkgconfig/openpa.pc

%files devel-static
%defattr(-,root,root)
%{_libdir}/*.a

%endif

%changelog
* Wed May  4 2016 ro@suse.de
- there is no libnuma on s390/s390x
* Wed Apr 20 2016 pth@suse.de
- Fix spec for -psm and -testsuite.
* Wed Apr 13 2016 pth@suse.de
- Update to 2.2rc1, mostly for the support of psm2 (fate#319240).
* Wed Sep 24 2014 pth@suse.de
- Update to mvapich2 2.0 GMC:
  * Features and Enhancements (since 2.0rc2):
  - Consider CMA in collective tuning framework
  * Bug-Fixes (since 2.0rc2):
  - Fix bug when disabling registration cache
  - Fix shared memory window bug when shared memory collectives
    are disabled.
  - Fix mpirun_rsh bug when running mpmd programs with no arguments
- Exclude Aarch64 for the time being as asm/timex.h seems to be missing
  from the glibc kernel headers.
* Tue Jun  3 2014 pth@suse.de
- Update to OFED 3.12 final.
* Mon May 26 2014 pth@suse.de
- Update to 2.0rc2:
  * Features and Enhancements (since 2.0rc1):
  - CMA support is now enabled by default
  - Optimization of collectives with CMA support
  - RMA optimizations for shared memory and atomic operations
  - Tuning RGET and Atomics operations
  - Tuning RDMA FP-based communication
  - MPI-T support for additional performance and control variables
  - The --enable-mpit-pvars=yes configuration option will now
    enable only MVAPICH2 specific variables
  - Large message transfer support for PSM interface
  - Optimization of collectives for PSM interface
  - Updated to hwloc v1.9
  * Bug-Fixes (since 2.0rc1):
  - Fix multicast hang when there is a single process on one node
    and more than one process on other nodes
  - Fix non-power-of-two usage of scatter-doubling-allgather algorithm
  - Fix for bcastzero type hang during finalize
  - Enhanced handling of failures in RDMA_CM based
    connection establishment
  - Fix for a hang in finalize when using RDMA_CM
  - Finish receive request when RDMA READ completes in RGET protocol
  - Always use direct RDMA when flush is used
  - Fix compilation error with --enable-g=all in PSM interface
  - Fix warnings and memory leaks
* Thu May 15 2014 pth@suse.de
- mvapich2-psm-devel requires infinipath-psm-devel.
- Remove redundent requires for the devel-static package.
* Wed May  7 2014 stefan.fent@suse.com
- remove typo in mvapich-s390_get_cycles.patch
* Tue Apr 29 2014 pth@suse.de
- Remove bogus 0 from spec.
* Mon Apr 28 2014 pth@suse.de
- Remove all additional mvapich specific CFLAGS and extra LIBS.
* Fri Apr 25 2014 pth@suse.de
- Fix ExclusiveArch
- Only PSM needs explicit configuration so drop the else branch
  in configure call.
- mvapich2 now builds in parallel so tell make.
* Thu Apr 24 2014 pth@suse.de
- Build Mvapich2 for Qlogic from its own mvapich2-psm.spec.
* Wed Apr 23 2014 pth@suse.de
- Add mvapich2-pthread_yield.patch to define GNU_SOURCE before
  including pthread.h to get pthread_yield declared.
* Wed Apr 23 2014 pth@suse.de
- Don't require libibcommon as it's gone with OFED 3.12.
* Wed Apr 16 2014 stefan.fent@suse.com
- add asm code from kernel to properly implement get_cycles on
  s390 and s390x (bnc #870424) (mvapich-s390_get_cycles.patch)
* Mon Apr  7 2014 pth@suse.de
- Fix spec so that testsuite builds correctly.
* Sat Apr  5 2014 pth@suse.de
- Update config.* to make it build on ppc64le.
* Thu Mar 27 2014 pth@suse.de
- Regenerate autotool files to get ppc64le recognized.
- The predefined platform macros for s390 are lower case not upcase.
* Wed Mar 26 2014 pth@suse.de
- Finally got the syntax for conditionals in spec right...
- Add a dummy implementation of get_cycles for s390x.
- Update to 2.0rc1 as this is a MPI-3 implementation. For
  detailed changes see.
- Fix options passed to mpi-selector
* Tue Mar 25 2014 pth@suse.de
- Include the two COPYRIGHT files in the package.
- BuildRequire kernel-headers on s390x.
- Fix spec file
* Wed Mar  5 2014 pth@suse.de
- Compile with support for PSM on ix86 (fate#315889).
- mvapich2 has a testsuite, so run it from a separate spec file.
* Mon Feb 10 2014 pth@suse.de
- Update to 1.9:
- Remove mvapich2-1.0.2-non-void-rtn.patch as the changes are in
  the upstream source.
- Reformat BuildRequires
* Fri Jan 24 2014 pth@suse.de
- Update to OFED 3.12 daily.
* Fri Feb 29 2008 - jjolly@suse.de
- Update to 1.0.2 from OFED 1.3 GA release
- Minor changes to return value patch
* Thu Jan 31 2008 - jjolly@suse.de
- Update to 1.0.1 from OFED 1.3 rc2
- Fixed several 'undefined return value' compile errors
* Tue Jul 10 2007 - hvogel@suse.de
- Initial Package, Version 0.9.8
